@@ -1,13 +1,17 @@
-from psycopg2.extensions import connection as Connection, cursor as Cursor
-from typing import Any, Callable, Dict, List, Tuple, Union
-from psycopg2 import Binary, connect as dbConnect
-from concurrent.futures import ThreadPoolExecutor
-from psycopg2.errors import ConnectionException
-from kh_common.logging import getLogger, Logger
-from kh_common.config.credentials import db
-from kh_common.sql.query import Query
-from functools import partial, wraps
 from asyncio import get_event_loop
+from concurrent.futures import ThreadPoolExecutor
+from functools import partial, wraps
+from typing import Any, Callable, Dict, List, Tuple, Union
+
+from psycopg2 import Binary
+from psycopg2 import connect as dbConnect
+from psycopg2.errors import ConnectionException
+from psycopg2.extensions import connection as Connection
+from psycopg2.extensions import cursor as Cursor
+
+from kh_common.config.credentials import db
+from kh_common.logging import Logger, getLogger
+from kh_common.sql.query import Query
 from kh_common.timing import Timer
 
 
